"""Collection of 2D Elements
"""


from .Element2D import *
from .RectangularScheme import *
from .TriangularScheme import *
from .Serendipity import *
from .Quadrilateral import *
from .LTriangular import *
from .QTriangular import *
